/**
 * JQUERY EXPECT
 * Uses jQuery to compare the equality of CSS property values on a rendered page
 *
 * Usage
 * ------
 * var bgEqual = expectCSS('body', 'font-family', 'Avenir, sans-serif');
 * console.log(bgEqual);
 *
 * License
 * ------
 * Copyright Upskew Pty. Ltd., 2017
 */

var expectCSS = function (selector, property, expectedValue) {
  var actualValue = $(selector).css(property);
  if (isColorProperty(property)) {
    return isColorEqual(actualValue, expectedValue);
  } else if (property === 'font-weight') {
    return isFontWeightEqual(actualValue, expectedValue);
  }
  return actualValue.replace(/\s+/g, '') === expectedValue.replace(/\s+/g, '');
}

function isColorProperty(property) {
  return property.indexOf('color') >= 0 || property === 'fill';
}

// Ignore differences in font weight notation by trying to convert to numerical
// notation. Assumes that only three font weight names are used by lessons.
var FONT_WEIGHT_MAPPING = {
  'thin': '100',
  'normal': '400',
  'bold': '700',
}
function isFontWeightEqual(actualValue, expectedValue) {
  var numericalActualValue = FONT_WEIGHT_MAPPING[actualValue] || actualValue;
  var numericalExpectedValue = FONT_WEIGHT_MAPPING[expectedValue] || expectedValue;
  if (numericalActualValue === numericalExpectedValue) {
    return true;
  }
  return false;
}

// Ignore differences in color notation
function isColorEqual(actualValue, expectedValue) {
  actualColorValue = jQuery.Color(actualValue);
  expectedColorValue = jQuery.Color(expectedValue);
  return actualColorValue.is(expectedColorValue);
}